@@ -4,7 +4,7 @@ use swc_css_ast::*;
 use swc_css_visit::VisitMutWith;
 
 use self::compress::{
-    angle::compress_angle, declaration::compress_declaration,
+    alpha_value::compress_alpha_value, angle::compress_angle, declaration::compress_declaration,
     easing_function::compress_easing_function, empty::compress_empty,
     frequency::compress_frequency, keyframes::compress_keyframes, length::compress_length,
     selector::compress_selector, time::compress_time,
@@ -15,6 +15,7 @@ mod compress;
 
 pub fn minify(stylesheet: &mut Stylesheet) {
     stylesheet.visit_mut_with(&mut compress_empty());
+    stylesheet.visit_mut_with(&mut compress_alpha_value());
     stylesheet.visit_mut_with(&mut compress_length());
     stylesheet.visit_mut_with(&mut compress_angle());
     stylesheet.visit_mut_with(&mut compress_time());
